#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.trigger_dagrun import TriggerDagRunOperator
from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_smart_ccc_chat', default_args=default_args,
schedule_interval="59 0-23/1 * * *",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="smart_ccc_chat_failed",
    html_content='<h3>您好，smart_ccc_chat作业失败，请及时处理" </h3>')

chat_records_feign = SSHOperator(
ssh_hook=sshHook,
task_id='chat_records_feign',
command='python3 /data/airflow/etl/API/chat_records_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

chat_records_load = SSHOperator(
ssh_hook=sshHook,
task_id='chat_records_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"chat_records_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

chat_records_feign >> chat_records_load

tr_chat_messages_4800 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_chat_messages_4800',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_chat_messages"},
depends_on_past=False, 
retries=3, 
dag=dag)

tr_chat_records_2337 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_chat_records_2337',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_chat_records"},
depends_on_past=False, 
retries=3, 
dag=dag)

chat_records_load >> tr_chat_records_2337
chat_records_load >> tr_chat_messages_4800
tr_chat_messages_4800 >> task_failed 
tr_chat_records_2337 >> task_failed 
