#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.trigger_dagrun import TriggerDagRunOperator
from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_smart_ccc_custom', default_args=default_args,
schedule_interval="0 0-23/1 * * *",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="smart_ccc_custom_failed",
    html_content='<h3>您好，smart_ccc_custom作业失败，请及时处理" </h3>')

customer_list_feign = SSHOperator(
ssh_hook=sshHook,
task_id='customer_list_feign',
command='python3 /data/airflow/etl/API/customer_list_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

customer_list_load = SSHOperator(
ssh_hook=sshHook,
task_id='customer_list_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"customer_list_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_list_feign >> customer_list_load

customer_labels_feign = SSHOperator(
ssh_hook=sshHook,
task_id='customer_labels_feign',
command='python3 /data/airflow/etl/API/customer_labels_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

customer_labels_load = SSHOperator(
ssh_hook=sshHook,
task_id='customer_labels_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"customer_labels_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_labels_feign >> customer_labels_load

tr_custom_details_5516 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_custom_details_5516',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_custom_details"},
depends_on_past=False, 
retries=3, 
dag=dag)

tr_custom_labels_8280 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_custom_labels_8280',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_custom_labels"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_detail_feign = SSHOperator(
ssh_hook=sshHook,
task_id='customer_detail_feign',
command='python3 /data/airflow/etl/API/customer_detail_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

customer_detail_load = SSHOperator(
ssh_hook=sshHook,
task_id='customer_detail_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"customer_detail_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_detail_feign >> customer_detail_load

customer_labels_load >> tr_custom_labels_8280
customer_list_load >> tr_custom_details_5516
tr_custom_details_5516 >> task_failed 
customer_detail_load >> task_failed 
